<?php
/**
 * Invoice Ninja (https://invoiceninja.com).
 *
 * @link https://github.com/invoiceninja/invoiceninja source repository
 *
 * @copyright Copyright (c) 2022. Invoice Ninja LLC (https://invoiceninja.com)
 *
 * @license https://www.elastic.co/licensing/elastic-license
 */

namespace App\Export\CSV;

use Illuminate\Support\Carbon;

class BaseExport
{

    protected function addDateRange($query)
    {

        $date_range = $this->input['date_range'];

        if(array_key_exists('date_key', $this->input) && strlen($this->input['date_key']) > 1)
            $this->date_key = $this->input['date_key'];
        
        try{

            $custom_start_date = Carbon::parse($this->input['start_date']);
            $custom_end_date = Carbon::parse($this->input['end_date']);    

        }
        catch(\Exception $e){

            $custom_start_date = now()->startOfYear();
            $custom_end_date = now();

        }
        
        switch ($date_range) {

            case 'all':
                return $query;
            case 'last7':
                return $query->whereBetween($this->date_key, [now()->subDays(7), now()])->orderBy($this->date_key, 'ASC');
            case 'last30':
                return $query->whereBetween($this->date_key, [now()->subDays(30), now()])->orderBy($this->date_key, 'ASC');
            case 'this_month':
                return $query->whereBetween($this->date_key, [now()->startOfMonth(), now()])->orderBy($this->date_key, 'ASC');
            case 'last_month':
                return $query->whereBetween($this->date_key, [now()->startOfMonth()->subMonth(), now()->startOfMonth()->subMonth()->endOfMonth()])->orderBy($this->date_key, 'ASC');
            case 'this_quarter':
                return $query->whereBetween($this->date_key, [(new \Carbon\Carbon('-3 months'))->firstOfQuarter(), (new \Carbon\Carbon('-3 months'))->lastOfQuarter()])->orderBy($this->date_key, 'ASC');
            case 'last_quarter':
                return $query->whereBetween($this->date_key, [(new \Carbon\Carbon('-6 months'))->firstOfQuarter(), (new \Carbon\Carbon('-6 months'))->lastOfQuarter()])->orderBy($this->date_key, 'ASC');
            case 'this_year':
                return $query->whereBetween($this->date_key, [now()->startOfYear(), now()])->orderBy($this->date_key, 'ASC');
            case 'custom':
                return $query->whereBetween($this->date_key, [$custom_start_date, $custom_end_date])->orderBy($this->date_key, 'ASC');
            default:
                return $query->whereBetween($this->date_key, [now()->startOfYear(), now()])->orderBy($this->date_key, 'ASC');

        }

    }

    protected function buildHeader() :array
    {

        $header = [];

        foreach($this->input['report_keys'] as $value){

            $key = array_search ($value, $this->entity_keys);
            
            $key = str_replace("item.", "", $key);
            $key = str_replace("invoice.", "", $key);
            $key = str_replace("client.", "", $key);
            $key = str_replace("contact.", "", $key);

            $header[] = ctrans("texts.{$key}");
        }

        return $header;
    }
}